==> haskell-ansi-wl-pprint-0.6.8.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-wl-pprint
version: 0.6.8.1
id: ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk
key: ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk
license: BSD3
maintainer: Edward Kmett <ekmett@gmail.com>
homepage: http://github.com/ekmett/ansi-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer for colored ANSI terminal output
description:
    This is a pretty printing library based on Wadler'\''s paper "A Prettier Printer". It has been enhanced with support for ANSI terminal colored output using the ansi-terminal package.
category: User Interfaces, Text
author: Daan Leijen, Max Bolingbroke
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal
abi: 5dd9f62bbccf0f5ea87688386a1940a6
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/ansi-wl-pprint-0.6.8.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/ansi-wl-pprint-0.6.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/ansi-wl-pprint-0.6.8.1
hs-libraries: HSansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk
depends:
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU base-4.10.0.0
abi-depends: ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-wl-pprint-0.6.8.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-wl-pprint
version: 0.6.8.1
id: ansi-wl-pprint-0.6.8.1-87Vp1rYcKt73B49zrIk7Nn
key: ansi-wl-pprint-0.6.8.1-87Vp1rYcKt73B49zrIk7Nn
license: BSD3
maintainer: Edward Kmett <ekmett@gmail.com>
homepage: http://github.com/ekmett/ansi-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer for colored ANSI terminal output
description:
    This is a pretty printing library based on Wadler'\''s paper "A Prettier Printer". It has been enhanced with support for ANSI terminal colored output using the ansi-terminal package.
category: User Interfaces, Text
author: Daan Leijen, Max Bolingbroke
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal
abi: e6a9bf0a855d772264f9d0892180e936
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/ansi-wl-pprint-0.6.8.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/ansi-wl-pprint-0.6.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/ansi-wl-pprint-0.6.8.1
hs-libraries: HSansi-wl-pprint-0.6.8.1-87Vp1rYcKt73B49zrIk7Nn
depends:
    ansi-terminal-0.6.3.1-LwW7QlDDdfVDOUh8Avykfz base-4.10.1.0
abi-depends: ansi-terminal-0.6.3.1-LwW7QlDDdfVDOUh8Avykfz=c4fcb4e64dfe3f3339acd03e710c93da
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
